# Sets the Playback Range field to a random n-second range within the file
# The default value is 30, which can me modified in the config file, or via
# command line through the --args option, or the value will be pulled from 
# an expression column in the view named "Playback Duration".
#
# See: http://yabb.jriver.com/interact/index.php?topic=86548.0

package RandomPlaybackRange 1.03;

use v5.16;
use strict;
use warnings;

my %options = (
    var => {
	playback_duration => 30,
    },
);

$DB::single = 1;

main::set_scriptlet_opts(\%options);

our %callbacks = (
    pre     => undef,
    perfile => \&do_perfile,
    post    => undef,
);

# Per-row callback function
sub do_perfile {
    my ($argstr, $field, $row) = @_;

    exists $row->{'duration'} or 
	die "The required Duration column is missing from the view.  Please add the Duration column.\nStopped";

    # use the view's Playback Duration value, or the default defined above
    my $playback_duration = $argstr || $row->{'playback duration'} || $options{'var'}{'playback_duration'};

    return { $field => 0, 'bookmark' => 0 }	 if $playback_duration eq 'clear';

    my @duration = split /:/, $row->{'duration'};
    my $duration = pop @duration;
    $duration +=   60 * pop @duration if @duration;
    $duration += 3600 * pop @duration if @duration;
    #say "Duration seconds: $duration";

    my ($start, $end) = (0, $duration);
    if ($playback_duration < $duration) {
	$start = int(rand($duration));
	$start = $duration - $playback_duration if $start + $playback_duration > $duration;
	$end = $start + $playback_duration;

    }

    $start *= 1000;
    $end *= 1000;
    main::debug "Playback Range: $start-$end";
    return { $field => "$start-$end", 'bookmark' => 0 };
}

1;
